@@ -78,6 +78,9 @@ static void rb_playlist_class_init (RBPlaylistClass *class);
 static void rb_playlist_init       (RBPlaylist      *playlist);
 static void rb_playlist_finalize   (GObject *object);
 
+const char * my_gnome_vfs_get_mime_type_with_data (const char *uri, gpointer *data);
+
+
 GtkType
 rb_playlist_get_type (void)
 {
@@ -612,14 +615,17 @@ rb_playlist_add_m3u (RBPlaylist *playlist, const char *url,
 			/* Try with a base */
 			char *fullpath, *base, sep;
 
+			retval = TRUE;			
+			
 			base = rb_playlist_base_url (url);
 			sep = (split_char[0] == '\n' ? '/' : '\\');
 			if (sep == '\\')
 				lines[i] = g_strdelimit (lines[i], "\\", '/');
 			fullpath = g_strdup_printf ("%s/%s", base, lines[i]);
-			if (rb_playlist_parse_recurse (playlist, fullpath,
-						       recurse_level) == TRUE)
-				retval = TRUE;
+			if (!rb_playlist_parse_recurse (playlist, fullpath,
+							recurse_level))
+				rb_playlist_add_one_url (playlist, fullpath, NULL);
+				
 			g_free (fullpath);
 			g_free (base);
 		}
@@ -1049,7 +1055,8 @@ rb_playlist_add_directory (RBPlaylist *playlist, const char *url,
 		char *str, *fullpath;
 
 		if (info->name != NULL && (strcmp (info->name, ".") == 0
-					|| strcmp (info->name, "..") == 0)) {
+					   || strcmp (info->name, "..") == 0
+					   || strncmp (info->name, ".Trash", strlen (".Trash")))) {
 			res = gnome_vfs_directory_read_next (handle, info);
 			continue;
 		}
