@@ -52,11 +52,13 @@ static struct
 {
 	const char *mimetype;
 	const char *plugin;
+	const char *human_name;
 } rb_metadata_type_map[] = {
-	{"application/x-id3", "id3tag"},
-	{"application/ogg", NULL},
-	{"audio/x-flac", "flactag"},
-	{"application/x-ape", NULL},
+	{"application/x-id3", "id3tag", "MP3"},
+	{"application/ogg", NULL, "Ogg"},
+	{"audio/x-flac", "flactag", "FLAC"},
+	{"application/x-ape", NULL, "MonkeysAudio"},
+	{"audio/x-mod", NULL, "MOD"},
 };
 
 static GObjectClass *parent_class = NULL;
@@ -111,7 +113,8 @@ rb_metadata_finalize (GObject *object)
 
 	md = RB_METADATA (object);
 
-	g_hash_table_destroy (md->priv->metadata);
+	if (md->priv->metadata)
+		g_hash_table_destroy (md->priv->metadata);
 
 	if (md->priv->pipeline)
 		gst_object_unref (GST_OBJECT (md->priv->pipeline));
@@ -244,6 +247,17 @@ rb_metadata_gst_field_to_gst_tag (RBMetaDataField field)
 		return NULL;
 	}
 }
+
+static const char *
+rb_metadata_gst_type_to_name (RBMetaData *md)
+{
+	int i;
+	for (i = 0; i < G_N_ELEMENTS (rb_metadata_type_map); i++)
+		if (!strcmp (rb_metadata_type_map[i].mimetype, md->priv->type))
+			return rb_metadata_type_map[i].human_name;
+	return NULL;
+}
+
 static void
 rb_metadata_gst_eos_cb (GstElement *element, RBMetaData *md)
 {
@@ -264,6 +278,20 @@ rb_metadata_gst_error_cb (GstElement *element,
 			  RBMetaData *md)
 {
 	rb_debug ("caught error: %s ", error->message);
+
+	if (error->domain == GST_STREAM_ERROR
+	    && error->code == GST_STREAM_ERROR_CODEC_NOT_FOUND) {
+		const char *human_element_hame = rb_metadata_gst_type_to_name (md);
+		if (human_element_hame) {
+			md->priv->error = g_error_new (RB_METADATA_ERROR,
+						       RB_METADATA_ERROR_MISSING_PLUGIN,
+						       _("There is no plugin installed to handle a %s file."),
+						       human_element_hame);
+			return;
+		}
+	}
+	
+	/* Fallthrough */
 	md->priv->error = g_error_new_literal (RB_METADATA_ERROR,
 					       RB_METADATA_ERROR_GENERAL,
 					       error->message);
