@@ -76,7 +76,9 @@ void			rb_playlist_manager_load_playlists (RBPlaylistManager *mgr);
 
 void			rb_playlist_manager_save_playlists (RBPlaylistManager *mgr);
 
-RBSource *		rb_playlist_manager_new_playlist (RBPlaylistManager *mgr, gboolean automatic);
+RBSource *		rb_playlist_manager_new_playlist (RBPlaylistManager *mgr,
+							  const char *suggested_name,
+							  gboolean automatic);
 
 G_END_DECLS
 
