@@ -128,12 +128,6 @@ static void rb_shell_corba_set_playing_time (PortableServer_Servant _servant,
 						   CORBA_long time, CORBA_Environment *ev);
 
 static Bonobo_PropertyBag rb_shell_corba_get_player_properties (PortableServer_Servant _servant, CORBA_Environment *ev);
-static void rb_shell_db_changed_cb (RhythmDB *db, RhythmDBEntry *entry,
-				    RBShell *shell);
-static void rb_shell_db_changed_prop_cb (RhythmDB *db, RhythmDBEntry *entry,
-					 RhythmDBPropType prop, const GValue *old,
-					 const GValue *new, RBShell *shell);
-
 
 static gboolean rb_shell_window_state_cb (GtkWidget *widget,
 					  GdkEvent *event,
@@ -328,7 +322,6 @@ struct RBShellPrivate
 
 	gboolean play_queued;
 
-	gboolean db_dirty;
 	guint async_state_save_id;
 
 	gboolean shutting_down;
@@ -614,7 +607,7 @@ rb_shell_sync_state (RBShell *shell)
 	}
 	
 	rb_debug ("saving playlists");
-	rb_playlist_manager_save_playlists_blocking (shell->priv->playlist_manager);
+	rb_playlist_manager_save_playlists (shell->priv->playlist_manager);
 
 	rb_debug ("saving db");
 	rhythmdb_read_lock (shell->priv->db);
@@ -652,21 +645,6 @@ idle_save_playlist_manager (RBPlaylistManager *mgr)
 	return TRUE;
 }
 
-static void
-rb_shell_db_changed_cb (RhythmDB *db, RhythmDBEntry *entry,
-			RBShell *shell)
-{
-	shell->priv->db_dirty = TRUE;
-}
-
-static void
-rb_shell_db_changed_prop_cb (RhythmDB *db, RhythmDBEntry *entry,
-			     RhythmDBPropType prop, const GValue *old, const GValue *new,
-			     RBShell *shell)
-{
-	rb_shell_db_changed_cb (db, entry, shell);
-}
-
 static void
 rb_shell_shutdown (RBShell *shell)
 {
@@ -976,9 +954,10 @@ shell_pb_get_prop (BonoboPropertyBag *bag,
 
 	case PROP_SHUFFLE:
 	{
-		char *play_order;
-		g_object_get (G_OBJECT (player), "play-order", &play_order, NULL);
-		BONOBO_ARG_SET_BOOLEAN (arg, !strcmp ("shuffle", play_order));
+		gboolean shuffle, repeat;
+		rb_shell_player_get_playback_state (player,
+						    &shuffle, &repeat);
+		BONOBO_ARG_SET_BOOLEAN (arg, shuffle);
 		break;
 	}
 
@@ -1184,6 +1163,10 @@ rb_shell_entry_changed_cb (GObject *object, GParamSpec *pspec, RBShell *shell)
 	
 	g_assert (strcmp (pspec->name, "playing-entry") == 0);
 	song_info = get_song_info_from_player (shell);
+	if (!song_info) {
+		rb_debug ("no song info returned!");
+		return;
+	}
 	arg = bonobo_arg_new (TC_GNOME_Rhythmbox_SongInfo);
 	arg->_value = (gpointer)song_info;
 	shell_notify_pb_changes (shell, "song", arg);
@@ -1291,18 +1274,6 @@ rb_shell_construct (RBShell *shell)
 			shell->priv->load_complete = TRUE;
 		}
 	}
-	g_signal_connect_object (G_OBJECT (shell->priv->db),
-				 "entry_added",
-				 G_CALLBACK (rb_shell_db_changed_cb),
-				 shell, 0);
-	g_signal_connect_object (G_OBJECT (shell->priv->db),
-				 "entry_changed",
-				 G_CALLBACK (rb_shell_db_changed_prop_cb),
-				 shell, 0);
-	g_signal_connect_object (G_OBJECT (shell->priv->db),
-				 "entry_deleted",
-				 G_CALLBACK (rb_shell_db_changed_cb),
-				 shell, 0);
 
 	rb_debug ("shell: setting up tray icon");
 	tray_deleted_cb (NULL, NULL, shell);
@@ -2074,8 +2045,7 @@ rb_shell_cmd_contents (BonoboUIComponent *component,
 	gnome_help_display ("rhythmbox.xml", NULL, &error);
 
 	if (error != NULL) {
-		g_warning (error->message);
-
+		rb_error_dialog ("%s", error->message);
 		g_error_free (error);
 	}
 }
@@ -2261,17 +2231,26 @@ rb_shell_quit (RBShell *shell)
 	bonobo_object_unref (BONOBO_OBJECT (shell));
 }
 
-static void
-rb_shell_load_complete_cb (RhythmDB *db, RBShell *shell)
+static gboolean
+idle_handle_load_complete (RBShell *shell)
 {
-	rb_debug ("load complete");
 	GDK_THREADS_ENTER ();
 
+	rb_debug ("load complete");
+
 	rb_playlist_manager_load_playlists (shell->priv->playlist_manager);
 	rb_shell_sync_selected_source (shell);
 	shell->priv->load_complete = TRUE;
 
 	GDK_THREADS_LEAVE ();
+
+	return FALSE;
+}
+
+static void
+rb_shell_load_complete_cb (RhythmDB *db, RBShell *shell)
+{
+	g_idle_add ((GSourceFunc) idle_handle_load_complete, shell);
 }
 
 static void
