@@ -36,7 +36,6 @@
 #include "rb-preferences.h"
 #include "rb-search-entry.h"
 #include "rb-debug.h"
-#include "rb-player.h"
 #include "rb-remote.h"
 #include "eel-gconf-extensions.h"
 
@@ -58,6 +57,10 @@ static void rb_source_header_search_cb (RBSearchEntry *search,
 					RBSourceHeader *header);
 static void rb_source_header_disclosure_toggled_cb (GtkToggleButton *disclosure,
 						    gpointer data);
+static void rb_source_header_gconf_search_text_changed_cb (GConfClient *client,
+							   guint cnxn_id,
+							   GConfEntry *entry,
+							   RBSourceHeader *header);
 static void rb_source_header_gconf_disclosure_changed_cb (GConfClient *client,
 							  guint cnxn_id,
 							  GConfEntry *entry,
@@ -80,7 +83,9 @@ struct RBSourceHeaderPrivate
 	GtkWidget *disclosure;
 
 	guint browser_notify_id;
+	guint search_notify_id;
 	const char *browser_key;
+	const char *search_key;
 };
 
 enum
@@ -179,14 +184,14 @@ rb_source_header_init (RBSourceHeader *header)
 			      NULL);
 	gtk_container_add (GTK_CONTAINER (ebox), GTK_WIDGET (header->priv->search));
 
-	g_signal_connect (G_OBJECT (header->priv->search), "search",
-			  G_CALLBACK (rb_source_header_search_cb), header);
+	g_signal_connect_object (G_OBJECT (header->priv->search), "search",
+				 G_CALLBACK (rb_source_header_search_cb), header, 0);
 
 	header->priv->disclosure = cddb_disclosure_new (_("Show _Browser"),
 							_("Hide _Browser"));
 	gtk_widget_set_sensitive (header->priv->disclosure, FALSE);
-	g_signal_connect (G_OBJECT (header->priv->disclosure), "toggled",
-			  G_CALLBACK (rb_source_header_disclosure_toggled_cb), header);
+	g_signal_connect_object (G_OBJECT (header->priv->disclosure), "toggled",
+				 G_CALLBACK (rb_source_header_disclosure_toggled_cb), header, 0);
 
 	gtk_table_attach_defaults (GTK_TABLE (header),
 			           header->priv->disclosure, 0, 2, 0, 1);
@@ -229,29 +234,39 @@ rb_source_header_set_property (GObject *object,
 		{
 			if (header->priv->browser_key)
 				eel_gconf_notification_remove (header->priv->browser_notify_id);
+			if (header->priv->search_key)
+				eel_gconf_notification_remove (header->priv->search_notify_id);
 
 			g_signal_handlers_disconnect_by_func (G_OBJECT (header->priv->selected_source),
 							      G_CALLBACK (rb_source_header_filter_changed_cb),
 							      header);
 		}
 
-		rb_source_header_clear_search (header);
-		
 		header->priv->selected_source = g_value_get_object (value);
 		rb_debug ("selected source %p", g_value_get_object (value));
 
 		if (header->priv->selected_source != NULL)
 		{
 			header->priv->browser_key = rb_source_get_browser_key (header->priv->selected_source);
+			header->priv->search_key = rb_source_get_search_key (header->priv->selected_source);
 			if (header->priv->browser_key)
 				header->priv->browser_notify_id
 					= eel_gconf_notification_add (header->priv->browser_key,
 								      (GConfClientNotifyFunc) rb_source_header_gconf_disclosure_changed_cb,
 								      header);
-			g_signal_connect (G_OBJECT (header->priv->selected_source),
-					  "filter_changed",
-					  G_CALLBACK (rb_source_header_filter_changed_cb),
-					  header);
+			if (header->priv->search_key) {
+				header->priv->search_notify_id
+					= eel_gconf_notification_add (header->priv->search_key,
+								      (GConfClientNotifyFunc) rb_source_header_gconf_search_text_changed_cb,
+								      header);
+
+				rb_search_entry_set_text (RB_SEARCH_ENTRY (header->priv->search),
+							  eel_gconf_get_string (header->priv->search_key));
+			}
+			g_signal_connect_object (G_OBJECT (header->priv->selected_source),
+						 "filter_changed",
+						 G_CALLBACK (rb_source_header_filter_changed_cb),
+						 header, 0);
 			gtk_widget_set_sensitive (GTK_WIDGET (header->priv->search),
 						  rb_source_can_search (header->priv->selected_source));
 			if (!header->priv->browser_key &&
@@ -334,14 +349,34 @@ rb_source_header_filter_changed_cb (RBSource *source,
 	/* rb_search_entry_clear (RB_SEARCH_ENTRY (header->priv->search)); */
 }
 
+static void
+rb_source_header_gconf_search_text_changed_cb (GConfClient *client,
+					       guint cnxn_id,
+					       GConfEntry *entry,
+					       RBSourceHeader *header)
+{
+	char *searchtext;
+
+	g_return_if_fail (header->priv->search_key != NULL);
+	
+	rb_debug ("gconf search text changed");
+
+	searchtext = eel_gconf_get_string (header->priv->search_key);
+
+	rb_search_entry_set_text (RB_SEARCH_ENTRY (header->priv->search),
+				  searchtext);
+
+	rb_source_search (header->priv->selected_source, searchtext);
+}
+
 static void
 rb_source_header_search_cb (RBSearchEntry *search,
 			    const char *text,
 			    RBSourceHeader *header)
 {
 	rb_debug  ("searching for \"%s\"", text);
-	
-	rb_source_search (header->priv->selected_source, text);
+
+	eel_gconf_set_string (header->priv->search_key, text);
 }
 
 void
